@@ -41,4 +41,24 @@ test_that("TreeDriftTest returns resonable results",
                DriftTest(mean.list, w.cov, FALSE)[-6])
 })
 
+test_that("TreeDriftTest returns resonable results",
+          {
+            library(ape)
+            data(bird.orders)
+            tree <- bird.orders
+            mean.list <- llply(tree$tip.label, function(x) rnorm(5))
+            names(mean.list) <- tree$tip.label
+            cov.matrix.list <- RandomMatrix(5, length(tree$tip.label))
+            names(cov.matrix.list) <- tree$tip.label
+            cov.matrix.list = cov.matrix.list[sample(1:length(cov.matrix.list))]
+            mean.list_2 = mean.list[sample(1:length(mean.list))]
+            w.cov <- PhyloW(tree, cov.matrix.list)$'32'
+            test.list <- TreeDriftTest(tree, mean.list_2, cov.matrix.list)
+            expect_is(test.list, 'list')
+            expect_equal(length(test.list), 13)
+            expect_equal(test.list[["32"]][-6], 
+                         DriftTest(mean.list[na.omit(tree$tip.label[phytools::getDescendants(tree, "32")])], 
+                                   w.cov, FALSE)[-6])
+          })
+
           
\ No newline at end of file
